@@ -13,6 +13,8 @@ sub get($self, $index) {
 
 1;
 
+# ABSTRACT: A way, a queue of stations
+
 __END__
 
 =pod
@@ -21,11 +23,24 @@ __END__
 
 =head1 NAME
 
-Evo::Way
+Evo::Way - A way, a queue of stations
 
 =head1 VERSION
 
-version 0.004
+version 0.005
+
+=head1 SYNOPSIS
+
+  use Evo::Manager;
+  my $mngr = Evo::Manager->new;
+
+  my $way = $mngr->build_way;
+  $way->add(sub { })->add(sub { });
+  my $station = $way->get(0);
+
+=head1 DESCRIPTION
+
+C<Evo::Way> is a subclass of C<Railway::Way>
 
 =head1 ATTRIBUTES
 
@@ -41,22 +56,7 @@ Get a station and clean it to free a memory
 
 =head2 add
 
-Add a station, wrapped by the L</"curry>
-
-# ABSTRACT: A way, a queue of stations
-
-=head1 Synopsis
-
-  use Evo::Manager;
-  my $mngr = Evo::Manager->new;
-
-  my $way = $mngr->build_way;
-  $way->add(sub { })->add(sub { });
-  my $station = $way->get(0);
-
-=head1 Description
-
-C<Evo::Way> is a subclass of C<Railway::Way>
+Add a station, wrapped by the L</"curry">
 
 =head1 AUTHOR
 
