@@ -11,6 +11,10 @@ sub w_dsl_init : prototype() {
   };
 }
 
+1;
+
+# ABSTRACT: A library with wrappers
+
 __END__
 
 =pod
@@ -19,11 +23,11 @@ __END__
 
 =head1 NAME
 
-Evo::Wrappers
+Evo::Wrappers - A library with wrappers
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 DESCRIPTION
 
@@ -37,8 +41,6 @@ Start DSL.
 Shifts first argument, save it to current under 'train' key,
 and invoke method with remaining arguments using L<Evo::Manager/"dsl_init">
 
-1;
-
 =head1 AUTHOR
 
 alexbyk.com
